import { LiveKeyFactory, OpgpLiveKey } from './live-key';
import { ProxyKeyFactory, OpgpProxyKey } from './proxy-key';
import { CsrKeyCache } from 'csrkey-cache';
import * as Promise from 'bluebird';
export declare type Eventual<T> = T | PromiseLike<T>;
export declare type OneOrMore<T> = T[] | T;
export interface OpgpServiceFactory {
    (config?: OpgpServiceFactoryConfig): OpgpService;
}
export interface OpgpServiceFactoryConfig {
    cache?: CsrKeyCache<OpgpLiveKey>;
    getLiveKey?: LiveKeyFactory;
    getProxyKey?: ProxyKeyFactory;
    openpgp?: any;
}
export interface OpgpService {
    configure(config?: Eventual<OpenpgpConfig>): Promise<OpenpgpConfig>;
    isValidKeyHandle(keyRef: Eventual<KeyRef>): Promise<boolean>;
    generateKey(user: Eventual<OneOrMore<UserId>>, opts?: Eventual<OpgpKeyOpts>): Promise<OpgpProxyKey>;
    getPublicKey(keyRef: Eventual<KeyRef>): Promise<OpgpProxyKey>;
    getKeysFromArmor(armor: Eventual<string>, opts?: Eventual<OpgpKeyringOpts>): Promise<OneOrMore<OpgpProxyKey>>;
    getArmorFromKey(keyRef: Eventual<KeyRef>): Promise<string>;
    unlock(keyRef: Eventual<KeyRef>, passphrase: Eventual<string>, opts?: Eventual<UnlockOpts>): Promise<OpgpProxyKey>;
    lock(keyRef: Eventual<KeyRef>, passphrase: Eventual<string>, opts?: Eventual<LockOpts>): Promise<OpgpProxyKey>;
    encrypt(keyRefs: Eventual<KeyRefMap>, plain: Eventual<string>, opts?: Eventual<EncryptOpts>): Promise<string>;
    decrypt(keyRefs: Eventual<KeyRefMap>, cipher: Eventual<string>, opts?: Eventual<DecryptOpts>): Promise<string>;
    sign(keyRefs: Eventual<OneOrMore<KeyRef>>, text: Eventual<string>, opts?: Eventual<SignOpts>): Promise<string>;
    verify(keyRefs: Eventual<OneOrMore<KeyRef>>, armor: Eventual<string>, opts?: Eventual<VerifyOpts>): Promise<string>;
}
export interface KeyRefMap {
    auth: OneOrMore<KeyRef>;
    cipher: OneOrMore<KeyRef>;
}
export declare type KeyRef = OpgpProxyKey | string;
export { OpgpProxyKey };
export interface OpgpKeyOpts {
    passphrase?: string;
    size?: number;
    unlocked?: boolean;
}
export declare type UserId = UserIdSpec | string;
export interface UserIdSpec {
    name?: string;
    email: string;
}
export interface OpenpgpConfig {
    prefer_hash_algorithm: number;
    encryption_cipher: number;
    compression: number;
    aead_protect: boolean;
    aead_protect_version: number;
    integrity_protect: boolean;
    ignore_mdc_error: boolean;
    rsa_blinding: boolean;
    use_native: boolean;
    zero_copy: boolean;
    debug: false;
    show_version: true;
    show_comment: true;
    versionstring: string;
    commentstring: string;
    keyserver: string;
    node_store: string;
}
export interface OpgpKeyringOpts {
}
export interface UnlockOpts {
}
export interface LockOpts {
}
export interface EncryptOpts {
}
export interface DecryptOpts {
}
export interface SignOpts {
}
export interface VerifyOpts {
}
export interface CommonOpts {
    valid: number;
}
declare const getOpgpService: OpgpServiceFactory;
export default getOpgpService;
